@@ -66,6 +66,7 @@ class PythonSearchConfiguration(EntriesGroup):
     simple_gui_font_size = 14
     _default_tags = None
     tags_dependent_inserter_marks = None
+    _initialization_time = None
 
     def __init__(
         self,
@@ -74,7 +75,7 @@ class PythonSearchConfiguration(EntriesGroup):
         entries_groups: Optional[List[EntriesGroup]] = None,
         supported_features: Optional[PythonSearchFeaturesSupport] = None,
         default_tags=None,
-        tags_dependent_inserter_marks: Optional[dict[str, Tuple[str, str]]]=None
+        tags_dependent_inserter_marks: Optional[dict[str, Tuple[str, str]]] = None,
     ):
         if entries:
             self.commands = entries
@@ -94,6 +95,10 @@ class PythonSearchConfiguration(EntriesGroup):
 
         self.tags_dependent_inserter_marks = tags_dependent_inserter_marks
 
+        from datetime import datetime
+
+        self._initialization_time = datetime.now()
+
 
 class ConfigurationLoader:
     """
@@ -110,10 +115,13 @@ class ConfigurationLoader:
 
         import sys
 
-        sys.path.insert(0, folder)
+        if folder not in sys.path:
+            sys.path.insert(0, folder)
+        import copy
+
         from entries_main import config
 
-        return config
+        return copy.deepcopy(config)
 
     def reload(self):
         """
@@ -124,7 +132,12 @@ class ConfigurationLoader:
         import entries_main
 
         importlib.reload(entries_main)
-        return entries_main.config
+
+        import copy
+
+        import entries_main
+
+        return copy.deepcopy(entries_main.config)
 
     def get_project_root(self):
         env_name = "PS_ENTRIES_HOME"
@@ -153,5 +166,3 @@ class ConfigurationLoader:
     def load_entries(self):
         config = self.load_config()
         return config.commands
-
-
