@@ -1,6 +1,8 @@
 from fastapi import FastAPI
 from fastapi.responses import PlainTextResponse
 
+from python_search.entry_type.classifier_inference import (EntryData,
+                                                           predict_entry_type)
 from python_search.events.latest_used_entries import RecentKeys
 from python_search.events.run_performed import RunPerformed, RunPerformedWriter
 
@@ -8,17 +10,16 @@ PORT = 8000
 
 app = FastAPI()
 from python_search.config import ConfigurationLoader
-from python_search.ranking.ranking import RankingGenerator
+from python_search.search.search import Search
 
-generator = RankingGenerator(ConfigurationLoader().load_config())
-ranking_result = generator.generate()
+generator = Search(ConfigurationLoader().load_config())
+ranking_result = generator.search()
 
 
 def reload_ranking():
     global generator
     global ranking_result
-    generator = RankingGenerator(ConfigurationLoader().reload())
-    ranking_result = generator.generate()
+    ranking_result = Search(ConfigurationLoader().reload()).search()
     return ranking_result
 
 
@@ -45,11 +46,15 @@ def health():
     from python_search.events.latest_used_entries import RecentKeys
 
     entries = RecentKeys().get_latest_used_keys()
+    run_id = None
+    if generator._inference is not None:
+        run_id = generator._inference.PRODUCTION_RUN_ID
 
     return {
         "keys_count": len(ConfigurationLoader().load_config().commands.keys()),
-        "run_id": generator._inference.PRODUCTION_RUN_ID,
+        "run_id": run_id,
         "latest_used_entries": entries,
+        "initialization_time": ConfigurationLoader().load_config()._initialization_time,
     }
 
 
@@ -60,12 +65,17 @@ def log_run(event: RunPerformed):
 
     RunPerformedWriter().write(event)
 
-    # regenerate the ranking after running a key
+    # regenerate the search after running a key
     reload()
 
     return event
 
 
+@app.post("/entry_type/classify")
+def predict_entry_type_endpoint(entry: EntryData):
+    return {"predicted_type": predict_entry_type(entry)}
+
+
 @app.get("/recent_history")
 def recent_history_endpoint():
     return RecentKeys().get_latest_used_keys()
